==> mangopaysdk-3.0.5.tar.gz: mangopaysdk-3.0.5/README.md <==
Mangopay Python SDK [![Build Status](https://travis-ci.org/Mangopay/mangopay2-python-sdk.svg?branch=master)](https://travis-ci.org/Mangopay/mangopay2-python-sdk)
=================================================

MangopaySDK is a Python client library to work with
[Mangopay REST API](http://docs.mangopay.com/api-references/).


Installation
------------

mangopaysdk requires: 

* [requests](https://pypi.python.org/pypi/requests)
* [blinker](https://pypi.python.org/pypi/blinker)

To install the package:

```
    pip install mangopaysdk
```

By installing this package with [pip](https://pypi.python.org/pypi/pip), all dependencies will be installed for you.


Documentation
-------------

For documentation and examples of usage for the Mangopay API please refer to: [API references](https://docs.mangopay.com/api-references/)

See [docs](https://github.com/Mangopay/mangopay2-python-sdk/blob/master/docs/usage.rst) to find examples.

License
-------------------------------------------------
MangopaySDK is distributed under MIT license, see LICENSE file.

Contact
-------------------------------------------------
Report bugs or suggest features using [issue tracker at GitHub](https://github.com/MangoPay/mangopay2-python-sdk-v2).


Account creation
-------------------------------------------------
You can get yourself a [free sandbox account](https://www.mangopay.com/signup/create-sandbox/) or sign up for a [production account](https://www.mangopay.com/signup/production-account/) (note that validation of your production account can take a few days, so think about doing it in advance of when you actually want to go live).

Inspiration
-----------

The data model of python-mangopay is highly inspired by [peewee](https://github.com/coleifer/peewee).

Credits
-----------

The inital basis of this SDK was generously coded and donated by [Ulule](https://www.ulule.com/)

==> mangopaysdk-3.42.0.tar.gz: mangopaysdk-3.42.0/README.md <==
Mangopay Python SDK [![Build Status](https://travis-ci.org/Mangopay/mangopay2-python-sdk.svg?branch=master)](https://travis-ci.org/Mangopay/mangopay2-python-sdk)
=================================================

MangopaySDK is a Python client library to work with
[Mangopay REST API](http://docs.mangopay.com/api-references/).


Installation
------------

mangopaysdk requires: 

* [requests](https://pypi.python.org/pypi/requests)
* [blinker](https://pypi.python.org/pypi/blinker)

To install the package:

```
    pip install mangopaysdk
```

By installing this package with [pip](https://pypi.python.org/pypi/pip), all dependencies will be installed for you.


Documentation
-------------

For documentation and examples of usage for the Mangopay API please refer to: [API references](https://docs.mangopay.com/api-references/)

See [docs](https://github.com/Mangopay/mangopay2-python-sdk/blob/master/docs/usage.rst) to find examples.

License
-------------------------------------------------
MangopaySDK is distributed under MIT license, see LICENSE file.

Contact
-------------------------------------------------
Report bugs or suggest features using [issue tracker at GitHub](https://github.com/Mangopay/mangopay2-python-sdk/issues).


Account creation
-------------------------------------------------
You can get yourself a free sandbox account or sign up for a production account by [registering on the Mangopay site](https://www.mangopay.com/start/) (note that validation of your production account involves several steps, so think about doing it in advance of when you actually want to go live).

Inspiration
-----------

The data model of python-mangopay is highly inspired by [peewee](https://github.com/coleifer/peewee).

Credits
-----------

The inital basis of this SDK was generously coded and donated by [Ulule](https://www.ulule.com/)
